{% load static %}
{% load i18n %}

{% spaceless %}
<div class="dynamic-array-widget">
  <ul>
    {% for subwidget in widget.subwidgets %}
      <li class="array-item" {% if widget.is_none %}data-isNone="true" style="display: none"{% endif %}>
        {% with widget=subwidget %}
          {% include widget.template_name %}
        {% endwith %}
        <div class="remove"><div class="remove_sign"></div></div>
      </li>
    {% endfor %}
  </ul>
  <div><button type="button" class="add-array-item">{% trans "Add another" %}</button></div>
</div>
{% endspaceless %}
