.dynamic-array-widget .array-item {
  display: flex;
  align-items: center;
}

.dynamic-array-widget .remove_sign {
  width: 10px;
  height: 2px;
  background: #a41515;
  border-radius: 1px;
}

.dynamic-array-widget .remove {
  height: 15px;
  display: flex;
  align-items: center;
  margin-left: 5px;
}

.dynamic-array-widget .remove:hover {
  cursor: pointer;
}

.dynamic-array-widget button {
  height: 20px;
  background: #79aec8;
  border-radius: 4px;
  color: #fff;
  cursor: pointer;
  border: none;
}

.dynamic-array-widget button:hover {
  background: #609ab6;
}
